<template>
    <div class="modal fade" tabindex="-1" role="dialog" :class="{ show: isVisible }"
         :style="{ display: isVisible ? 'block' : 'none' }">
        <div :class="['modal-dialog', size]" role="document">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title">{{ title }}</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" @click="emitClose"></button>
                </div>
                <div class="modal-body">
                    <slot name="body"></slot>
                </div>
                <div class="modal-footer">
                    <BaseButton class="btn-outline-primary" @click="emitClose">
                        Batal
                    </BaseButton>
                    <slot name="footer"></slot>
                </div>
            </div>
        </div>
    </div>
    <div class="modal-backdrop fade" :class="{ show: isVisible }" v-if="isVisible"></div>

</template>

<script setup>

import BaseButton from "@/Components/Button/BaseButton.vue";

defineProps({
    title: {
        type: String,
        default: "Modal Title",
    },
    size: {
        type: String,
        default: "modal-md",
    },
    isVisible: {
        type: Boolean,
        default: false,
    },
});
const emit = defineEmits(["close"]);
const emitClose = () => {
    emit("close");
};
</script>

<style scoped>
.modal.fade {
    transition: opacity 0.3s ease;
}

.modal.fade:not(.show) {
    opacity: 0;
}

.modal.show {
    opacity: 1;
}

.modal.fade.show {
    display: block;
    background-color: rgba(0, 0, 0, 0.5);
}
</style>
